Skip to contents

utility for pkg devs to update or create documentation of datasets in the package

Usage

dataset_documenter(
  varname,
  title = "(varname) dataset",
  description = "",
  details = "",
  seealso = "",
  saveinpackage = TRUE,
  scriptname = paste0("datacreate_", varname, ".R")
)

Arguments

varname

character string text of name of object, like "blockgroupstats"

title

same as the roxygen2 tag

description

same as the roxygen2 tag

details

same as the roxygen2 tag

seealso

same as the roxygen2 tag

saveinpackage

if TRUE, puts quoted dataset name at end of file, and otherwise puts NULL at end of file

scriptname

name of the data-raw script that creates this dataset, used in the header comment of the documentation file. Defaults to datacreate_<varname>.R (i.e., built from the varname); pass it explicitly when one script creates several datasets (e.g., datacreate_names_pct_as_fraction.R).

Value

name of .R file where documentation was written