Skip to contents

simple way to see the table of summary stats on special areas and features like schools

Usage

ejam2areafeatures(ejamitout)

Arguments

ejamitout

output from ejamit()

Value

a data frame with the summary of flagged areas

Details

In this table, summary stats mean the following:

  • The "flag" or "yesno" indicators here are population weighted sums, so they show how many people from the analysis live in blockgroups that overlap with the given special type of area, such as non-attainment areas under the Clean Air Act.

  • The "number" indicators are counts for each site in the ejamit()$results_overall table, but here are summarized as what percent of residents overall in the analysis have AT LEAST ONE OR MORE of that type of site in the blockgroup they live in.

  • The "pctno" or % indicators are summarized as what % of the residents analyzed lack the critical service.

The columns of the table are:

  • Indicator - plain-English name of the indicator

  • Percent_of_these_Sites - % of the analyzed sites where the indicator is present/flagged (or the average of the site-level percentages, for the two % indicators)

  • Percent_of_these_People - % of the analyzed residents living in a blockgroup with the feature or overlap

  • Percent_of_all_People_Nationwide - the same % but among all US residents

  • ratio - Percent_of_these_People / Percent_of_all_People_Nationwide

  • Percent_of_all_People_Statewide - the same % but among all residents of the state(s) analyzed. Where sites span multiple states, this is the average of the state-level percentages weighted by the analyzed population in each state (i.e., the average among all the residents at these sites, using the statewide value in each resident's state), analogous to how ratios to State averages are calculated for other indicators in results_overall.

  • ratio_to_state_avg - Percent_of_these_People / Percent_of_all_People_Statewide

  • rname - the variable name of the indicator, like "num_school" or "yesno_tribal"