helper function to rename variables that are colnames of data.frame
Source:R/fixcolnames.R
fixcolnames_anyoldtype.Rdlike fixcolnames() but can try multiple values as oldtypes
Usage
fixcolnames_anyoldtype(
namesnow,
oldtypes = c("longname", "apiname", "api_synonym", "csvname", "acsname", "oldname"),
newtype = "r"
)Arguments
- namesnow
same as in
fixcolnames()- oldtypes
vector of oldtype values, where one is like oldtype param in
fixcolnames()- newtype
same as in
fixcolnames()