Skip to contents

Use EPA Program ID to see FRS Facility Registry Service data on those EPA-regulated sites

Usage

frs_from_programid(programname, programid)

Arguments

programname

name of EPA program that the programid is from: "RCRAINFO" is the programname and "XJW000000174" is the programid if the full record was RCRAINFO:XJW000000174

programid

like "XJW000000174" "RCRAINFO" is the programname and "XJW000000174" is the programid if the full record was RCRAINFO:XJW000000174

Value

relevant rows of the table in data.table format called frs, which has column names that are "lat" "lon" "REGISTRY_ID" "PRIMARY_NAME" "NAICS" "PGM_SYS_ACRNMS"

Examples

 x <- frs_from_programid(
   testinput_program_sys_id$program[1],
   testinput_program_sys_id$pgm_sys_id[1]
 )
 x
 mapfast(x)