Skip to contents

Together with the metadata_mapping script, this can be used annually to update the metadata for datasets in a package. It just makes it easier to set a few metadata attributes similarly for a number of data elements, for example, to add new or update existing attributes.

Usage

metadata_add(
  x,
  metadata = NULL,
  update_date_saved_in_package = TRUE,
  update_ejam_package_version = TRUE
)

Arguments

x

dataset (or any object, unquoted, i.e., not its name but the object itself) whose metadata (stored as attributes) you want to update or create EJAM, EJSCREEN, and other dataset versions and release dates are tracked in DESCRIPTION

metadata

optional - when omitted, it checks metadata_mapping using get_metadata_mapping(). Can provide a list of key=value attributes to add

update_date_saved_in_package

can set to FALSE to avoid changing this attribute

update_ejam_package_version

can set to FALSE to avoid changing this attribute

Value

returns x but with new or altered attributes

Details

to update only the ejam_package_version attribute of every data item:

metadata_update_attr()

This utility would be used in scripts in EJAM/data-raw/ to add metadata to objects like x before use_data(x, overwrite = TRUE)

Note that by adding attributes, this function changes a vector so that is.vector() will no longer be true!

Examples

  # metadata_check() # internal function
  x <- data.frame(a=1:10,b=1001:1010)
  # x <- EJAM:::metadata_add(x) # internal function
  attributes(x)