Skip to contents

This is used to figure out which state contains each point (facility/site).

Usage

states_shapefile

Format

An object of class sf (inherits from data.frame) with 56 rows and 16 columns.

Details

This is used by state_from_latlon() to find which state is associated with each point that the user wants to analyze. That is needed to report indicators in the form of State-specific percentiles (e.g., a score that is at the 80th percentile within Texas). It is created by the package via a script at EJAM/data-raw/datacreate_states_shapefile.R which downloads the data from Census Bureau.

It includes 50 states, DC, PR, and 4 island areas (GU, MP, VI, AS).

Source: https://www2.census.gov/geo/tiger/TIGER2024/STATE/tl_2024_us_state.zip