Validate and reshape 1 row of ejamit results to prep for formatting as gt table/report
Source:R/table_gt_.R
table_gt_format_step1.RdReshapes a few columns of a 1 row data.table into a tall multirow data.frame.
Arguments
- ejamit_results_1row
table in data.table format (or data.frame) like testoutput_ejamit_100pts_1miles$results_overall from something like ejamit(testpoints_100, radius = 1)$results_overall
- type
demog or envt to specify which type of table