Skip to contents

data.frame of 100 percentiles and means (about 100 rows) in the USA overall, across all locations (e.g., blockgroups in blockgroupstats) for a set of indicators such as percent low income. Each column is one indicator (or specifies the percentile).

This should be similar to the lookup tables in the gdb on the FTP site of EJSCREEN, except it also has data for additional population subgroups.

For EJAM v3, blockgroupstats may include AS/GU/MP/VI at the blockgroup dataset, EJSCREEN export, and map-data visibility level. Those Island Areas normally have NA demographic values because ACS does not cover them; available environmental values can still contribute to the relevant non-demographic lookup columns.

For details on how the table was made, see source package files in data-raw folder.

See also statestats

Usage

usastats

Format

An object of class data.frame with 102 rows and 114 columns.