custom version of ejamit() for calculating user-provided indicators
Source:R/PROXIMITY_FUNCTIONS.R
custom_ejamit.Rdcustom version of ejamit() for calculating user-provided indicators
Usage
custom_ejamit(
sitepoints,
radius = 3,
fips = NULL,
shapefile = NULL,
custom_blockgroupstats = blockgroupstats,
countcols = names_wts,
popmeancols = names_these,
wtcols = names_wts,
custom_formulas = NULL,
custom_cols = NULL,
custom_map_headernames = map_headernames,
shape = NULL,
shp = NULL
)Arguments
- sitepoints
see
ejamit()- radius
see
ejamit()- fips
see
ejamit()- shapefile
see
ejamit()- custom_blockgroupstats
like blockgroupstats but with custom indicators, one value per blockgroup, with colnames bgid, bgfips, pop
- countcols
vector of colnames in custom_blockgroupstats to be aggregated as sums of counts, like population counts
- popmeancols
vector of colnames in custom_blockgroupstats to be aggregated as weighted means, population weighted or with other weights
- wtcols
vector of colnames to use as the weights for wtd means, same length as popmeancols, but not used yet
- custom_formulas
character vector of formulas, like
formulas_ejscreen_acs$formula, not used yet- custom_cols
not used yet
- custom_map_headernames
like map_headernames but for the custom indicators
- shape, shp
aliases (synonyms) for shapefile
Value
returns the output of custom_doaggregate()