Count how often each search term appears across files
Source:R/utils_PACKAGE_DEV.R
found_in_N_files_T_times.RdFor each term in pattern_vector, runs find_in_files() and
reports both how many files contain the term and how many matching lines
were found overall.
Arguments
- pattern_vector
character vector of search terms
- path
optional path like "./R"
- ignorecomments
if
TRUE, ignore matches in lines that are just comments rather than active source code- ...
passed to
find_in_files()such asignore.caseorfilename_pattern
Examples
EJAM:::found_in_N_files_T_times(c("gray", "grey"), path = "./R", quiet = TRUE)